.. _index:

Documentation for species
=========================

*species* is a toolkit for analyzing spectral and photometric data of planetary and substellar atmospheres. The package has been developed and is maintained by |stolker|.

.. |stolker| raw:: html

	<a href="https://people.phys.ethz.ch/~stolkert/" target="_blank">Tomas Stolker</a>

.. figure:: _images/species.jpg
   :width: 30%
   :align: center

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   installation
   running

.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   overview
   configuration
   examples
   modules

.. toctree::
   :maxdepth: 2
   :caption: About species

   contributing
   about